@@ -196,9 +196,6 @@ class CanvasMainWindow(QMainWindow):
     def setup_ui(self):
         """Setup main canvas ui
         """
-
-        log.info("Setting up Canvas main window.")
-
         # Two dummy tool bars to reserve space
         self.__dummy_top_toolbar = FakeToolBar(
             objectName="__dummy_top_toolbar")
@@ -243,8 +240,9 @@ class CanvasMainWindow(QMainWindow):
         frame.setWidget(self.scheme_widget)
 
         # Window 'title'
+        self.__update_window_title()
         self.setWindowFilePath(self.scheme_widget.path())
-        self.scheme_widget.pathChanged.connect(self.setWindowFilePath)
+        self.scheme_widget.pathChanged.connect(self.__update_window_title)
         self.scheme_widget.modificationChanged.connect(self.setWindowModified)
 
         # QMainWindow's Dock widget
@@ -815,6 +813,15 @@ class CanvasMainWindow(QMainWindow):
 
         self.__update_from_settings()
 
+    def __update_window_title(self):
+        path = self.current_document().path()
+        if path:
+            self.setWindowTitle("")
+            self.setWindowFilePath(path)
+        else:
+            self.setWindowFilePath("")
+            self.setWindowTitle(self.tr("Untitled [*]"))
+
     def setWindowFilePath(self, filePath):  # type: (str) -> None
         if sys.platform == "darwin":
             super().setWindowFilePath(filePath)
@@ -927,6 +934,7 @@ class CanvasMainWindow(QMainWindow):
             if i != -1:
                 popup.setModel(model)
                 popup.setRootIndex(model.index(i, 0))
+                popup.adjustSize()
                 button = self.quick_category.buttonForAction(action)
                 pos = popup_position_from_source(popup, button)
                 action = popup.exec(pos)
@@ -1011,6 +1019,7 @@ class CanvasMainWindow(QMainWindow):
         window.setAttribute(Qt.WA_DeleteOnClose)
         window.setGeometry(self.geometry().translated(20, 20))
         window.setStyleSheet(self.styleSheet())
+        window.setWindowIcon(self.windowIcon())
         if self.widget_registry is not None:
             window.set_widget_registry(self.widget_registry)
         window.restoreState(self.saveState(self.SETTINGS_VERSION),
@@ -1158,6 +1167,20 @@ class CanvasMainWindow(QMainWindow):
                     return
                 f.seek(0, os.SEEK_SET)
                 new_scheme = self.new_scheme_from_contents_and_path(f, filename)
+        except readwrite.UnsupportedFormatVersionError:
+            mb = QMessageBox(
+                self, windowTitle=self.tr("Error"),
+                icon=QMessageBox.Critical,
+                text=self.tr("Unsupported format version"),
+                informativeText=self.tr(
+                    "The file was saved in a format not supported by this "
+                    "application."
+                ),
+                detailedText="".join(traceback.format_exc()),
+            )
+            mb.setAttribute(Qt.WA_DeleteOnClose)
+            mb.setWindowModality(Qt.WindowModal)
+            mb.open()
         except Exception as err:
             mb = QMessageBox(
                 parent=self, windowTitle=self.tr("Error"),
