@@ -18,7 +18,7 @@ from AnyQt.QtWidgets import QGraphicsScene, QGraphicsItem
 from AnyQt.QtGui import QPainter, QColor, QFont
 from AnyQt.QtCore import (
     Qt, QPointF, QRectF, QSizeF, QLineF, QBuffer, QObject, QSignalMapper,
-    QT_VERSION
+    QParallelAnimationGroup, QT_VERSION
 )
 from AnyQt.QtSvg import QSvgGenerator
 from AnyQt.QtCore import pyqtSignal as Signal
@@ -120,6 +120,7 @@ class CanvasScene(QGraphicsScene):
 
         self.__channel_names_visible = True
         self.__node_animation_enabled = True
+        self.__animations_temporarily_disabled = False
 
         self.user_interaction_handler = None  # type: Optional[UserInteraction]
 
@@ -140,6 +141,8 @@ class CanvasScene(QGraphicsScene):
             lambda node: self.link_item_activated.emit(node)
         )
 
+        self.__anchors_opened = False
+
     def clear_scene(self):  # type: () -> None
         """
         Clear (reset) the scene.
@@ -331,12 +334,12 @@ class CanvasScene(QGraphicsScene):
         item = self.new_node_item(node.description)
 
         if node.position:
-            pos = QPointF(*node.position)  # type: ignore
+            pos = QPointF(*node.position)
             item.setPos(pos)
 
         item.setTitle(node.title)
-        item.setProcessingState(node.processing_state)  # type: ignore
-        item.setProgress(node.progress)  # type: ignore
+        item.setProcessingState(node.processing_state)
+        item.setProgress(node.progress)
 
         for message in node.state_messages():
             item.setStateMessage(message)
@@ -384,6 +387,8 @@ class CanvasScene(QGraphicsScene):
         """
         Remove `item` (:class:`.NodeItem`) from the scene.
         """
+        desc = item.widget_description
+
         self.activated_mapper.removeMappings(item)
         self.hovered_mapper.removeMappings(item)
         self.position_change_mapper.removeMappings(item)
@@ -479,8 +484,8 @@ class CanvasScene(QGraphicsScene):
         Construct and return a new :class:`.LinkItem`
         """
         item = items.LinkItem()
-        item.setSourceItem(source_item)
-        item.setSinkItem(sink_item)
+        item.setSourceItem(source_item, source_channel)
+        item.setSinkItem(sink_item, sink_channel)
 
         def channel_name(channel):
             # type: (Union[OutputSignal, InputSignal, str]) -> str
@@ -493,10 +498,6 @@ class CanvasScene(QGraphicsScene):
         sink_name = channel_name(sink_channel)
 
         fmt = "<b>{0}</b>&nbsp; \u2192 &nbsp;<b>{1}</b>"
-        item.setToolTip(
-            fmt.format(escape(source_name),
-                       escape(sink_name))
-        )
 
         item.setSourceName(source_name)
         item.setSinkName(sink_name)
@@ -570,19 +571,19 @@ class CanvasScene(QGraphicsScene):
 
         if isinstance(scheme_annot, scheme.SchemeTextAnnotation):
             item = items.TextAnnotation()
-            x, y, w, h = scheme_annot.rect  # type: ignore
+            x, y, w, h = scheme_annot.rect
             item.setPos(x, y)
             item.resize(w, h)
             item.setTextInteractionFlags(Qt.TextEditorInteraction)
 
-            font = font_from_dict(scheme_annot.font, item.font()) # type: ignore
+            font = font_from_dict(scheme_annot.font, item.font())
             item.setFont(font)
             item.setContent(scheme_annot.content, scheme_annot.content_type)
             scheme_annot.content_changed.connect(item.setContent)
         elif isinstance(scheme_annot, scheme.SchemeArrowAnnotation):
             item = items.ArrowAnnotation()
             start, end = scheme_annot.start_pos, scheme_annot.end_pos
-            item.setLine(QLineF(QPointF(*start), QPointF(*end)))  # type: ignore
+            item.setLine(QLineF(QPointF(*start), QPointF(*end)))
             item.setColor(QColor(scheme_annot.color))
 
         scheme_annot.geometry_changed.connect(
@@ -712,6 +713,10 @@ class CanvasScene(QGraphicsScene):
         """
         return [item for item in self.__node_items if item.isSelected()]
 
+    def selected_link_items(self):
+        # type: () -> List[LinkItem]
+        return [item for item in self.__link_items if item.isSelected()]
+
     def selected_annotation_items(self):
         # type: () -> List[Annotation]
         """
@@ -755,6 +760,15 @@ class CanvasScene(QGraphicsScene):
                              self.node_output_links(node_item)))
         return neighbors
 
+    def set_widget_anchors_open(self, enabled):
+        if self.__anchors_opened == enabled:
+            return
+        self.__anchors_opened = enabled
+
+        for item in self.node_items():
+            item.inputAnchorItem.setAnchorOpen(enabled)
+            item.outputAnchorItem.setAnchorOpen(enabled)
+
     def _on_position_change(self, item):
         # type: (NodeItem) -> None
         # Invalidate the anchor point layout for the node and schedule a layout.
@@ -772,10 +786,10 @@ class CanvasScene(QGraphicsScene):
         annot = self.sender()
         item = self.__item_for_annotation[annot]
         if isinstance(annot, scheme.SchemeTextAnnotation):
-            item.setGeometry(QRectF(*annot.rect))              # type: ignore
+            item.setGeometry(QRectF(*annot.rect))
         elif isinstance(annot, scheme.SchemeArrowAnnotation):
-            p1 = item.mapFromScene(QPointF(*annot.start_pos))  # type: ignore
-            p2 = item.mapFromScene(QPointF(*annot.end_pos))    # type: ignore
+            p1 = item.mapFromScene(QPointF(*annot.start_pos))
+            p2 = item.mapFromScene(QPointF(*annot.end_pos))
             item.setLine(QLineF(p1, p2))
         else:
             pass
@@ -857,6 +871,30 @@ class CanvasScene(QGraphicsScene):
             return
         super().contextMenuEvent(event)
 
+    def dragEnterEvent(self, event):
+        if self.user_interaction_handler and \
+                self.user_interaction_handler.dragEnterEvent(event):
+            return
+        super().dragEnterEvent(event)
+
+    def dragMoveEvent(self, event):
+        if self.user_interaction_handler and \
+                self.user_interaction_handler.dragMoveEvent(event):
+            return
+        super().dragMoveEvent(event)
+
+    def dragLeaveEvent(self, event):
+        if self.user_interaction_handler and \
+                self.user_interaction_handler.dragLeaveEvent(event):
+            return
+        super().dragLeaveEvent(event)
+
+    def dropEvent(self, event):
+        if self.user_interaction_handler and \
+                self.user_interaction_handler.dropEvent(event):
+            return
+        super().dropEvent(event)
+
     def set_user_interaction_handler(self, handler):
         # type: (UserInteraction) -> None
         if self.user_interaction_handler and \
@@ -867,7 +905,13 @@ class CanvasScene(QGraphicsScene):
 
         self.user_interaction_handler = handler
         if handler:
+            if self.__node_animation_enabled:
+                self.__animations_temporarily_disabled = True
+                self.set_node_animation_enabled(False)
             handler.start()
+        elif self.__animations_temporarily_disabled:
+            self.__animations_temporarily_disabled = False
+            self.set_node_animation_enabled(True)
 
     def __str__(self):
         return "%s(objectName=%r, ...)" % \
